@@ -323,7 +323,7 @@ class App(object):
                         .replace("\\", "-")
                         .replace("&", "")
                         .replace("!", "")
-                        , ext), 'wb', encoding='utf-8') as readme:
+                        , ext), 'wb') as readme:
                     if hasattr(file, "RawData"):
                         file_content = base64.b64decode(file.RawData.cdata)
                         readme.write(file_content)
