@@ -14,7 +14,7 @@ class LongArrField(BaseField):
     def to_file(self):
         super().to_file()
 
-        with open("{}/PROPERTIES.md".format(self.field_dir), 'a+') as file:
+        with open("{}/PROPERTIES.md".format(self.field_dir), 'a+', encoding='utf-8') as file:
             file.write("## List Item\n")
             file.write("|id|origId|orderNo|source|name|code|mainItemId|isDefault|\n")
             file.write("|---|---|---|---|---|---|---|---|\n")
