@@ -30,7 +30,7 @@ class Portal(object):
         # fichier de propriétés
         if not os.path.exists(self.portal_dir):
             os.makedirs(self.portal_dir)
-        file = open("{}/PROPERTIES.md".format(self.portal_dir), 'w+')
+        file = open("{}/PROPERTIES.md".format(self.portal_dir), 'w+', encoding='utf-8')
         with file:
             # nom de l'objet
             file.write("# {}\n".format(self.name))
@@ -45,11 +45,11 @@ class Portal(object):
             for el in self.properties["children"]:
                 file.write("- {} : {}\n".format(el.__dict__["_name"], el.__dict__["cdata"]))
 
-        header = open("{}/header.html".format(self.portal_dir), 'w+')
+        header = open("{}/header.html".format(self.portal_dir), 'w+', encoding='utf-8')
         with header:
             header.write(self.header.decode("utf-8"))
 
-        footer = open("{}/footer.html".format(self.portal_dir), 'w+')
+        footer = open("{}/footer.html".format(self.portal_dir), 'w+', encoding='utf-8')
         with footer:
             footer.write(self.footer.decode("utf-8"))
 
